# Documentation

* [Che Cosa?](./01-cosa.md)
* [How to install Cosa](./02-install.md)
* [Supported boards & chips](./03-boards.md)
* [Built-in drivers](./04-drivers.md)
* [External Libraries, Tools and Applications](./05-libraries.md)
